bmab_giplus: Calculate the GI+ index for a single arm (Bernoulli rewards)

View source: R/bmab.R

bmab_giplusR Documentation

Calculate the GI+ index for a single arm (Bernoulli rewards)

Description

The GI+ index is an upper bound for the Gittins index.

Usage

bmab_giplus(Sigma, n, gamma, tol = 5e-04, upper = FALSE)

Arguments

Sigma

Numeric > 0. Value of Sigma for the arm.

n

Numeric > Sigma > 0. Value of n for the arm.

gamma

Numeric in (0, 1). Reward discount factor.

tol

Numeric > 0. Absolute accuracy required.

upper

if TRUE, the upper end of the interval is returned, otherwise the midpoint.

Value

A GI+ index value.


jedwards24/gittins documentation built on Oct. 13, 2023, 4:17 p.m.