bmab_kgi: Calculate the knowledge gradient index for a single arm...

View source: R/bmab.R

bmab_kgiR Documentation

Calculate the knowledge gradient index for a single arm (Bernoulli rewards)

Description

The KGI is an lower bound for the Gittins index.

Usage

bmab_kgi(Sigma, n, gamma)

Arguments

Sigma

Numeric > 0. Value of Sigma for the arm.

n

Numeric > Sigma > 0. Value of n for the arm.

gamma

Numeric in (0, 1). Reward discount factor.

Details

This is an exact closed form calculation. Arguments Sigma and n can be supplied as vectors in which case a vector of index values will be returned.

Value

An index value or a vector of values.


jedwards24/gittins documentation built on Oct. 13, 2023, 4:17 p.m.