View source: R/calibrate_arm.R
| calibrate_arm | R Documentation |
Performs iterative reduction of an interval using calibration with value function FUN.
calibrate_arm(FUN, lb, ub, tol, ...)
FUN |
A value function. |
lb |
Initial lower end of interval. |
ub |
Initial upper end of interval. |
tol |
Absolute accuracy required. |
... |
Other arguments passed to |
A vector of lower and upper end of an interval containing the true value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.