| nmab_gi_multiple | R Documentation |
This assumes mu = 0 as the GI for other values can then be derived by simple addition. See
?nmab_gi for more detail on the problem and computation parameters.
nmab_gi_multiple(n_range, gamma, tau, N, xi, delta, tol = 5e-04)
n_range |
Numeric vector giving values of n (all greater than 0). |
gamma |
Numeric in (0, 1). Reward discount factor. |
tau |
Numeric > 0. Observation precision. |
N |
Integer >= 2. Time horizon used. |
xi |
Numeric > 0. Value of xi (entent of dynamic program state space). |
delta |
Numeric > 0. Value of delta (fineness of discretisation in the dynamic program). |
tol |
Numeric > 0. Absolute accuracy required. |
A data frame of GI vales with a row for each n in n_range. The parameters used are
attached as an attribute params.
n1 <- nmab_gi_multiple(1:4, gamma = 0.9, tau = 1, N = 30, xi = 3, delta = 0.02, tol = 5e-4)
n1
attr(n1, "params")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.