nmab_kgi: Calculate the knowledge gradient index for a single arm...

View source: R/nmab.R

nmab_kgiR Documentation

Calculate the knowledge gradient index for a single arm (normal rewards)

Description

The index is an lower bound for GI.

Usage

nmab_kgi(Sigma, n, gamma, tau, tol = 5e-04, ub = NA, lower = FALSE)

Arguments

Sigma

Numeric. Value of Sigma for the arm (Bayesian reward).

n

Numeric > 0. Value of n for the arm (Bayesian number of observation).

gamma

Numeric in (0, 1). Reward discount factor.

tau

Numeric > 0. Observation precision.

tol

Numeric > 0. Absolute accuracy required.

ub

Optional upper bound for the index.

lower

If TRUE, the lower end of the interval is returned, otherwise the midpoint.

Value

A vector of GI values.


jedwards24/gittins documentation built on Oct. 13, 2023, 4:17 p.m.