| bmab_giplus | R Documentation |
The GI+ index is an upper bound for the Gittins index.
bmab_giplus(Sigma, n, gamma, tol = 5e-04, upper = FALSE)
Sigma |
Numeric > 0. Value of Sigma for the arm. |
n |
Numeric > Sigma > 0. Value of n for the arm. |
gamma |
Numeric in (0, 1). Reward discount factor. |
tol |
Numeric > 0. Absolute accuracy required. |
upper |
if TRUE, the upper end of the interval is returned, otherwise the midpoint. |
A GI+ index value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.