| bmab_kgi | R Documentation |
The KGI is an lower bound for the Gittins index.
bmab_kgi(Sigma, n, gamma)
Sigma |
Numeric > 0. Value of Sigma for the arm. |
n |
Numeric > Sigma > 0. Value of n for the arm. |
gamma |
Numeric in (0, 1). Reward discount factor. |
This is an exact closed form calculation. Arguments Sigma and n can be supplied as vectors in
which case a vector of index values will be returned.
An index value or a vector of values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.